import pandas as pd

def clean_dataframe(df):
    """Cleans a DataFrame by:
    - Replacing spaces in column names with underscores.
    - Replacing NaN values with 0 for int and bigint columns.
    - Replacing NaN values with 0.0 for float, double, numeric, and decimal columns.
    - Replacing NaN values with 'Unknown' for non-numeric columns.
    - Stripping leading/trailing whitespace from string columns.
    """
    df = df.copy()  # Work on a copy to avoid modifying the original DataFrame

    # 🔹 Replace spaces in column names with underscores
    df.columns = [col.strip().replace(" ", "_") for col in df.columns]

    for col in df.columns:
        if pd.api.types.is_integer_dtype(df[col]):  # Integer (int, bigint)
            df[col] = df[col].fillna(0).astype(int)  # Ensure it stays an integer
        elif pd.api.types.is_float_dtype(df[col]):  # Float, double, numeric, decimal
            df[col] = df[col].fillna(0.0).astype(float)  # Ensure it stays a float
        else:  # Non-numeric (string, object, etc.)
            df[col] = df[col].astype(str).str.strip().replace({"nan": "Unknown", "None": "Unknown"})

    return df
